@@ -28,7 +28,7 @@ extern char *confFileName;
 void finish_gconjugue(){
   int h, w;
 
-  /* Save the window dimensions */
+  /* Save window dimensions */
   gtk_window_get_size((GtkWindow*)window1, &w, &h);
   if(w != initWidth || h != initHeight){
     FILE *F = fopen(confFileName, "w");
@@ -152,10 +152,9 @@ void on_hcontents_activate(){
       "Um verbo não classificado no próprio banco como seguidor de um dos "
       "paradigmas, tem seu paradigma deduzido pelo programa pela comparação da "
       "sua terminação com a de alguns verbos. As comparações são feitas na "
-      "seqüência abaixo e são interrompidas quando é encontrada uma "
+      "sequência abaixo e são interrompidas quando é encontrada uma "
       "coincidência de terminações:\n\n"
       "   \4çar\5  abraçar\n"
-      "   \4iar\5  apoiar\n"
       "   \4gar\5  chegar\n"
       "   \4car\5  comunicar\n"
       "   \4oar\5  magoar\n"
