@@ -162,7 +162,7 @@ Paradigma *pegarParadigma(const char *v)
 Paradigma *deduzirParadigma(char *v)
 {
   Paradigma *p01 = pegarParadigma("abraçar");
-  Paradigma *p02 = pegarParadigma("apoiar");
+  /*Paradigma *p02 = pegarParadigma("apoiar");*/
   Paradigma *p03 = pegarParadigma("chegar");
   Paradigma *p04 = pegarParadigma("comunicar");
   Paradigma *p05 = pegarParadigma("magoar");
@@ -198,12 +198,12 @@ Paradigma *deduzirParadigma(char *v)
     case 'a':
       switch(c2){
 	case (char)0xa7: return p01; break;
-	case 'i':
+	/*case 'i':
 			 if(l > 3 && v[l-4] == 'o')
 			   return p02;
 			 else
 			   return p07;
-			 break;
+			 break;*/
 	case 'g': return p03; break;
 	case 'c': return p04; break;
 	case 'o': return p05; break;
